@@ -96,7 +96,7 @@ class ADSLTicketTestCase(unittest.TestCase):
             'mm_fiber_coverage',
             'vdf_fiber_coverage',
             'orange_fiber_coverage',
-            'change_address',
+            'type',
             'landline_phone_number',
             'product',
             'previous_internal_provider',
